@@ -209,6 +209,7 @@ class ConfigurationMain(ResultsMain):
                     "investment_evaluation_method": self.ui.investment_evaluation_method_ComboBox,
                     "max_investments_evluation_number": self.ui.max_investments_evluation_number_spinBox,
                     "investment_evaluation_obj_func": self.ui.investment_evaluation_objfunc_ComboBox,
+                    "firm_capacity_share": self.ui.firmCapacityShareSpinBox,
                 },
                 "stochastic": {
                     "method": self.ui.stochastic_pf_method_comboBox,
@@ -467,10 +468,6 @@ class ConfigurationMain(ResultsMain):
                     plugin_info.investments_fcn.alias
                 ] = plugin_info.investments_fcn.function_ptr
 
-        # create combobox model for the plugin investments
-        lst = list(self.plugins_investment_evaluation_method_dict.keys())
-        self.ui.plugins_investment_evaluation_method_ComboBox.setModel(gf.get_list_model(lst))
-
     def launch_plugin(self, fcn: PluginFunction):
         """
         Action wrapper to launch the plugin
